==> nextcloud-21.0.3.tgz: nextcloud/apps/federatedfilesharing/l10n/sc.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Nche cheres agiùnghere sa cumpartzidura remota {name} dae {owner}@{remote}?",
    "Remote share" : "Cumpartzidura remota",
    "Remote share password" : "Cumpartzidura remota crae",
    "Cancel" : "Annulla",
    "Add remote share" : "Agiunghe cumpartzidura remota",
    "Copy" : "Còpia",
    "Copied!" : "Copiadu!",
    "Not supported!" : "Non suportadu!",
    "Press ⌘-C to copy." : "Incarca ⌘-C pro copiare.",
    "Press Ctrl-C to copy." : "incarca Ctrl-C pro copiare.",
    "Invalid Federated Cloud ID" : " ID de sa nue virtuale federada non bàlidu",
    "Server to server sharing is not enabled on this server" : "Sa cumpartzidura intre serbidores no est ativada in custu serbidore",
    "Couldn't establish a federated share." : "No at fatu a istabilire una cumpartzidura federada.",
    "Couldn't establish a federated share, maybe the password was wrong." : "No at fatu a istabilire una cumpartzidura federada, fortzis sa crae no es curreta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Dimanda de cumpartzidura federada fata, as a retzire unu cumbidu. controlla is notèificas tuas.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No at fatu a istabilire una cumpartzidura federada, paret chi su serbidore de federare siat de tropu tempus (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No est permèitidu de imbiare cumpartziduras de grupu federadas dae custu serbidore.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Cumpartzidura %1$s faddida, ca custu elementu e giai cumpartzidu cun s'utente %2$s",
    "Not allowed to create a federated share with the same user" : "Non faghet a istabilire una cumpartzidura federada cun su pròpiu utente",
    "Federated shares require read permissions" : "Cumpartziduras federadas rechedent permissos de letura",
    "File is already shared with %s" : "S'archìviu est giai cumpartzidu cun %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sa cumpartzidura %1$s faddida, non at a fatu a agatare %2$s, mancari su serbidore immoe non si podet cuntatare o impreat unu tzertificadu firmadu da issu etotu.",
    "Could not find share" : "No at fatu a agatare sa cumpartzidura",
    "Federated sharing" : "Cumpartzidura federada",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "As retzidu \"%3$s\" comente cumpartzidura remota dae %4$s (%1$s) (pro parte de %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "As retzidu {share} comente cumpartziduraremota dae {user} (pro parte de {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "As retzidu \"%3$s\" comente cumpartidura remota dae %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : " As retzidu {share} comente cumpartzidura remota dae {user}",
    "Accept" : "Atzeta",
    "Decline" : "Refuda",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Cumpartzi cun megus tràmite s'ID meu de nue virtuale federada #Nextcloud, càstia %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Cumpartzi cun megus tràmite s'ID meu de nue virtuale federada #Nextcloud Federated Cloud ID",
    "Sharing" : "Cumpartzidura",
    "Federated file sharing" : "Cumpartzidura archìviu federadu",
    "Provide federated file sharing across servers" : "Frunit una cumpartzidura de archìvios federados intre serbidores",
    "Federated Cloud Sharing" : "Cumpartzidura Nue virtuale federada",
    "Open documentation" : "Aberi documentatzione",
    "Adjust how people can share between servers." : "Règula comente is persones podent cumpartzire intre serbidores.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permite a is utentes in custu serbidore de imbiare cumpartziduras ad àteros serbidores (custu sèberu permitet fintzas s'atzessu WebDAV a is cumpartziduras pùblicas)",
    "Allow users on this server to receive shares from other servers" : "Permite a is utentes in custu serbidore pro retzire cumpartziduras dae àteros serbidores",
    "Allow users on this server to send shares to groups on other servers" : "Permite a is utentes in custu serbidore de imbiare cumpartzidura a grupos in àteros serbidores",
    "Allow users on this server to receive group shares from other servers" : "Permite a is utentes in custu serbidore de retzire cumpartziduras de grupu dae àteros serbidores",
    "Search global and public address book for users" : "Chirca is utentes in sa rubrica globale e pùblica",
    "Allow users to publish their data to a global and public address book" : "Permite a is utentes de publicare is datos issoro in una rubrica globale e pùblica",
    "Federated Cloud" : "Nue virtuale federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Podes cumpartzire con chie si siat mpreet su serbidore Nextcloud o àteros serbidores Open Cloud Mesh (OCM) cumpatìbiles. Ti bastat de nche insertare s'ID issoro de sa nue virtuale federada in sa bentana de cumpartzidura. Assimìgiat a persone@nue.esempru.com ",
    "Your Federated Cloud ID:" : "S'ID tuo de sa nue virtuale federada:",
    "Share it so your friends can share files with you:" : " Condividilo in modo che i tuoi amici possano condividere file con te:",
    "Add to your website" : "Agiunghe a su situ ìnternet tuo",
    "Share with me via Nextcloud" : "Cumpartzi cun megus tràmite Nextcloud",
    "HTML Code:" : "Còdighe HTML:",
    "Allow users on this server to send shares to other servers" : "Permite a is utentes in custu serbidore de imbiare cumpartziduras a àteros serbidores"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.4.tgz: nextcloud/apps/federatedfilesharing/l10n/sc.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Nche cheres agiùnghere sa cumpartzidura remota {name} dae {owner}@{remote}?",
    "Remote share" : "Cumpartzidura remota",
    "Remote share password" : "Cumpartzidura remota crae",
    "Cancel" : "Annulla",
    "Add remote share" : "Agiunghe cumpartzidura remota",
    "Copy" : "Còpia",
    "Copied!" : "Copiadu!",
    "Not supported!" : "Non suportadu!",
    "Press ⌘-C to copy." : "Incarca ⌘-C pro copiare.",
    "Press Ctrl-C to copy." : "incarca Ctrl-C pro copiare.",
    "Invalid Federated Cloud ID" : " ID de sa nue virtuale federada non bàlidu",
    "Server to server sharing is not enabled on this server" : "Sa cumpartzidura intre serbidores no est ativada in custu serbidore",
    "Couldn't establish a federated share." : "No at fatu a istabilire una cumpartzidura federada.",
    "Couldn't establish a federated share, maybe the password was wrong." : "No at fatu a istabilire una cumpartzidura federada, fortzis sa crae no es curreta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Dimanda de cumpartzidura federada fata, as a retzire unu cumbidu. controlla is notèificas tuas.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No at fatu a istabilire una cumpartzidura federada, paret chi su serbidore de federare siat de tropu tempus (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No est permèitidu de imbiare cumpartziduras de grupu federadas dae custu serbidore.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Cumpartzidura %1$s faddida, ca custu elementu e giai cumpartzidu cun s'utente %2$s",
    "Not allowed to create a federated share with the same user" : "Non faghet a istabilire una cumpartzidura federada cun su pròpiu utente",
    "Federated shares require read permissions" : "Cumpartziduras federadas rechedent permissos de letura",
    "File is already shared with %s" : "S'archìviu est giai cumpartzidu cun %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sa cumpartzidura %1$s faddida, non at a fatu a agatare %2$s, mancari su serbidore immoe non si podet cuntatare o impreat unu tzertificadu firmadu da issu etotu.",
    "Could not find share" : "No at fatu a agatare sa cumpartzidura",
    "Federated sharing" : "Cumpartzidura federada",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "As retzidu \"%3$s\" comente cumpartzidura remota dae %4$s (%1$s) (pro parte de %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "As retzidu {share} comente cumpartziduraremota dae {user} (pro parte de {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "As retzidu \"%3$s\" comente cumpartidura remota dae %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : " As retzidu {share} comente cumpartzidura remota dae {user}",
    "Accept" : "Atzeta",
    "Decline" : "Refuda",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Cumpartzi cun megus tràmite s'ID meu de nue virtuale federada #Nextcloud, càstia %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Cumpartzi cun megus tràmite s'ID meu de nue virtuale federada #Nextcloud Federated Cloud ID",
    "Sharing" : "Cumpartzidura",
    "Federated file sharing" : "Cumpartzidura archìviu federadu",
    "Provide federated file sharing across servers" : "Frunit una cumpartzidura de archìvios federados intre serbidores",
    "Federated Cloud Sharing" : "Cumpartzidura Nue virtuale federada",
    "Open documentation" : "Aberi documentatzione",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Règula comente is persones podent cumpartzire tra serbidores. Includit cumpartzidura tra utentes in custu serbidore e puru si sunt impreende cumpartziduras federadas.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permite a is utentes in custu serbidore de imbiare cumpartziduras ad àteros serbidores (custu sèberu permitet fintzas s'atzessu WebDAV a is cumpartziduras pùblicas)",
    "Allow users on this server to receive shares from other servers" : "Permite a is utentes in custu serbidore pro retzire cumpartziduras dae àteros serbidores",
    "Allow users on this server to send shares to groups on other servers" : "Permite a is utentes in custu serbidore de imbiare cumpartzidura a grupos in àteros serbidores",
    "Allow users on this server to receive group shares from other servers" : "Permite a is utentes in custu serbidore de retzire cumpartziduras de grupu dae àteros serbidores",
    "Search global and public address book for users" : "Chirca is utentes in sa rubrica globale e pùblica",
    "Allow users to publish their data to a global and public address book" : "Permite a is utentes de publicare is datos issoro in una rubrica globale e pùblica",
    "Federated Cloud" : "Nue virtuale federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Podes cumpartzire con chie si siat mpreet su serbidore Nextcloud o àteros serbidores Open Cloud Mesh (OCM) cumpatìbiles. Ti bastat de nche insertare s'ID issoro de sa nue virtuale federada in sa bentana de cumpartzidura. Assimìgiat a persone@nue.esempru.com ",
    "Your Federated Cloud ID:" : "S'ID tuo de sa nue virtuale federada:",
    "Share it so your friends can share files with you:" : " Condividilo in modo che i tuoi amici possano condividere file con te:",
    "Add to your website" : "Agiunghe a su situ ìnternet tuo",
    "Share with me via Nextcloud" : "Cumpartzi cun megus tràmite Nextcloud",
    "HTML Code:" : "Còdighe HTML:",
    "Adjust how people can share between servers." : "Règula comente is persones podent cumpartzire intre serbidores."
},
"nplurals=2; plural=(n != 1);");
